pub fn from<T>(base_uri: Uri, req: T) -> Request<Body>where
T: IntoRequest,Expand description
A request to download the entire tree.
The body of the returned key is a Get serialized to JSON form.
pub fn from<T>(base_uri: Uri, req: T) -> Request<Body>where
T: IntoRequest,A request to download the entire tree.
The body of the returned key is a Get serialized to JSON form.