pub struct Cas {
pub key: Vec<u8>,
pub old: Option<Vec<u8>>,
pub new: Option<Vec<u8>>,
}Expand description
Compare and swap. Capable of unique creation, conditional modification, or deletion.
If old is None, this will only set the value if it doesn’t exist yet. If new is None, will delete the value if old is correct. If both old and new are Some, will modify the value if old is correct.
If Tree is read-only, will do nothing.
Fields
key: Vec<u8>old: Option<Vec<u8>>new: Option<Vec<u8>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Cas
impl<'de> Deserialize<'de> for Cas
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl IntoResponse for Cas
impl IntoResponse for Cas
Sourceimpl Ord for Cas
impl Ord for Cas
Sourceimpl PartialOrd for Cas
impl PartialOrd for Cas
Sourceimpl RequestType for Cas
impl RequestType for Cas
impl Eq for Cas
impl StructuralPartialEq for Cas