IntoBody

Trait IntoBody 

pub trait IntoBody {
    type Body: Serialize;

    // Required method
    fn into_body(self) -> Self::Body;
}
Types that may be converted into a serialized JSON body for a hyper request.

Required Associated Types

type Body: Serialize

The body of the request, capable of being serialized to JSON.

Required Methods

fn into_body(self) -> Self::Body

Convert self into the serializable Body type.

Implementors