IntoResponse

Trait IntoResponse 

pub trait IntoResponse {
    // Required method
    fn into_response(self, _: Arc<Tree>) -> Response<Body>;
}
Types that may be produced in response to some request.

Required Methods

fn into_response(self, _: Arc<Tree>) -> Response<Body>

Respond to the given request body, updating the sled::Tree as necessary.

Implementors