Struct sled_web::server::Config [−][src]
pub struct Config {
pub addr: SocketAddr,
}Configuration for the server.
Fields
addr: SocketAddr
The socket address to which the server will bind and listen for HTTP requests.
Defaults to localhost:3000. E.g. ([127, 0, 0, 1], 3000).
Methods
impl Config[src]
impl Configpub const DEFAULT_IP: [u8; 4]
DEFAULT_IP: [u8; 4] = [127, 0, 0, 1]
The default IP address used if a socket address is not specified.
pub const DEFAULT_PORT: u16
DEFAULT_PORT: u16 = 3000
The default port used if a socket address is not specified.
pub const DEFAULT_ADDR: ([u8; 4], u16)
DEFAULT_ADDR: ([u8; 4], u16) = (<Self>::DEFAULT_IP, <Self>::DEFAULT_PORT)
The default socket address used if one is not specified.