Struct sled_web::server::ConfigBuilder [−][src]
pub struct ConfigBuilder {
pub addr: Option<SocketAddr>,
}A type used for building a Config.
Fields
addr: Option<SocketAddr>
Methods
impl ConfigBuilder[src]
impl ConfigBuilderⓘImportant traits for &'a mut Rpub fn addr<T>(&mut self, addr: T) -> &mut Self where
T: Into<SocketAddr>, [src]
ⓘImportant traits for &'a mut R
pub fn addr<T>(&mut self, addr: T) -> &mut Self where
T: Into<SocketAddr>, The socket address to which the server will bind and listen for HTTP requests.
Defaults to localhost:3000. E.g. ([127, 0, 0, 1], 3000).
pub fn build(&mut self) -> Config[src]
pub fn build(&mut self) -> ConfigBuild the Config type, replacing None values with defaults where necessary.