Functions to simplify the construction of requests along with request types that can be serialized to and from the JSON body.
Structs
- Cas
- Compare and swap. Capable of unique creation, conditional modification, or deletion.
- Del
- Delete the entry at the given key.
- Flush
- Flushes any pending IO buffers to disk to ensure durability.
- Get
- Get a single entry from the DB, identified by the given unique key.
- Iter
- Iterate over all entries within the
Tree. - Max
- Retrieve the entry with the greatest
Keyin theTree. - Merge
- Merge a new value into the total state for a key.
- Pred
- Retrieve the entry that precedes the
Key. - Pred
Incl - Retrieve the entry that precedes or includes the
Key. - Scan
- Iterate over all entries within the
Treethat start at or follow the given key. - Scan
Range - Iterate over all entries within the
Treewithin the given key range. - Set
- Set the entry with the given key and value, replacing the original if one exists.
- Succ
- Retrieve the entry that follows the
Key. - Succ
Incl - Retrieve the entry that follows or includes the
Key.
Traits
- Into
Body - Types that may be converted into a serialized JSON body for a hyper request.
- Into
Request - Types that may be directly converted into a hyper Request.
- Request
Type - Types that represent a request being made to the server.
Functions
- cas
- Shorthand for
from(base_uri, Cas { key, old, new }). - del
- Shorthand for
from(base_uri, Del { key }). - flush
- Shorthand for
from(base_uri, Flush). - from
- A request to download the entire tree.
- get
- Shorthand for
from(base_uri, Get { key }). - iter
- Shorthand for
from(base_uri, Iter). - max
- Shorthand for
from(base_uri, Max). - merge
- Shorthand for
from(base_uri, Merge { key, value }). - pred
- Shorthand for
from(base_uri, Pred { key }). - pred_
incl - Shorthand for
from(base_uri, PredIncl { key }). - scan
- Shorthand for
from(base_uri, Scan { key }). - scan_
range - Shorthand for
from(base_uri, ScanRange { start, end }). - set
- Shorthand for
from(base_uri, Set { key, value }). - succ
- Shorthand for
from(base_uri, Succ { key }). - succ_
incl - Shorthand for
from(base_uri, SuccIncl { key }).