Module sled_web::request [−][src]
Functions to simplify the construction of requests along with request types that can be serialized to and from the JSON body.
Structs
| Cas |
Compare and swap. Capable of unique creation, conditional modification, or deletion. |
| Del |
Delete the entry at the given key. |
| Flush |
Flushes any pending IO buffers to disk to ensure durability. |
| Get |
Get a single entry from the DB, identified by the given unique key. |
| Iter |
Iterate over all entries within the |
| Max |
Retrieve the entry with the greatest |
| Merge |
Merge a new value into the total state for a key. |
| Pred |
Retrieve the entry that precedes the |
| PredIncl |
Retrieve the entry that precedes or includes the |
| Scan |
Iterate over all entries within the |
| ScanRange |
Iterate over all entries within the |
| Set |
Set the entry with the given key and value, replacing the original if one exists. |
| Succ |
Retrieve the entry that follows the |
| SuccIncl |
Retrieve the entry that follows or includes the |
Traits
| IntoBody |
Types that may be converted into a serialized JSON body for a hyper request. |
| IntoRequest |
Types that may be directly converted into a hyper Request. |
| RequestType |
Types that represent a request being made to the server. |
Functions
| cas |
Shorthand for |
| del |
Shorthand for |
| flush |
Shorthand for |
| from |
A request to download the entire tree. |
| get |
Shorthand for |
| iter |
Shorthand for |
| max |
Shorthand for |
| merge |
Shorthand for |
| pred |
Shorthand for |
| pred_incl |
Shorthand for |
| scan |
Shorthand for |
| scan_range |
Shorthand for |
| set |
Shorthand for |
| succ |
Shorthand for |
| succ_incl |
Shorthand for |