Struct sled_web::request::Cas[][src]

pub struct Cas {
    pub key: Vec<u8>,
    pub old: Option<Vec<u8>>,
    pub new: Option<Vec<u8>>,
}

Compare and swap. Capable of unique creation, conditional modification, or deletion.

If old is None, this will only set the value if it doesn't exist yet. If new is None, will delete the value if old is correct. If both old and new are Some, will modify the value if old is correct.

If Tree is read-only, will do nothing.

Fields