pub trait IntoBody { type Body: Serialize; // Required method fn into_body(self) -> Self::Body; }
Types that may be converted into a serialized JSON body for a hyper request.
The body of the request, capable of being serialized to JSON.
Convert self into the serializable Body type.
self
Body