pub trait IntoRequest: RequestType + IntoBody {
// Required method
fn into_request(self, base_uri: Uri) -> Request<Body>;
}Expand description
Types that may be directly converted into a hyper Request.
Required Methods
Sourcefn into_request(self, base_uri: Uri) -> Request<Body>
fn into_request(self, base_uri: Uri) -> Request<Body>
The base_uri should include only the scheme and host - the path and query will be
retrieved via RequestType::PATH_AND_QUERY.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.