pub trait IntoResponse {
// Required method
fn into_response(self, _: Arc<Tree>) -> Response<Body>;
}Expand description
Types that may be produced in response to some request.
pub trait IntoResponse {
// Required method
fn into_response(self, _: Arc<Tree>) -> Response<Body>;
}Types that may be produced in response to some request.