pub fn new(
config: Config,
tree: Arc<Tree>,
) -> impl Future<Item = (), Error = Error>Expand description
Build the hyper Server with the given configuration and sled::Tree.
Returns a Future representing the Server’s computation.
To create and run your own server you can use the response function which simply translates
requests to response futures.